import Auth from '@/student/layout/auth'
import { router, rootRouter } from './routes-common'

type metaType = {
  isRegister: boolean
}

const noLoginRouter = [
  {
    path: '/share-music-sheet',
    name: 'share-music-sheet',
    component: () => import('@/teacher/share-page/share-music-sheet/index'),
    meta: {
      title: '分享乐曲'
    }
  },
  {
    path: '/leaderboard',
    component: () => import('@/student/leaderboard/index'),
    meta: {
      title: '曲目挑战排行榜'
      // isExternal: true // 是否外部浏览器可以打开
    }
  },
  {
    path: '/payCenter',
    name: 'payCenter',
    component: () => import('@/views/adapay/pay-center'),
    meta: {
      title: '支付'
    }
  },
  {
    path: '/payDefine',
    name: 'payDefine',
    component: () => import('@/views/adapay/pay-define'),
    meta: {
      title: '支付'
    }
  },
  {
    path: '/payResult',
    name: 'payResult',
    component: () => import('@/views/adapay/pay-result'),
    meta: {
      title: '支付'
    }
  },
  {
    path: '/tradeDetail',
    name: 'tradeDetail',
    component: () => import('@/views/trade/trade-detail'),
    meta: {
      title: '交易详情'
    }
  },
  {
    path: '/helpCenter',
    name: 'helpCenter',
    component: () => import('@/views/article-center/help-center')
  },
  {
    path: '/helpCenterDetail',
    name: 'helpCenterDetail',
    component: () => import('@/views/article-center/help-center-detail')
  }
]

export default [
  {
    path: '/',
    component: Auth,
    children: [
      // ...router,
      {
        path: '/login',
        name: 'login',
        component: () => import('@/tenant/layout/login'),
        meta: {
          isRegister: false
        } as metaType
      },
      {
        path: '/music-album',
        component: () => import('@/tenant/music/album/index'),
        meta: {
          title: '专辑'
        }
      },
      {
        path: '/music-album-detail/:id',
        name: 'music-album-detail',
        component: () => import('@/tenant/music/album-detail'),
        meta: {
          title: '专辑详情'
        }
      },
      {
        path: '/music-list',
        component: () => import('@/tenant/music/list'),
        meta: {
          title: '曲谱列表'
        }
      },
      {
        path: '/train-list',
        component: () => import('@/tenant/music/train-list'),
        meta: {
          title: '声部训练'
        }
      },
      {
        path: '/music-detail',
        component: () => import('@/tenant/music/music-detail/new-index'),
        meta: {
          title: '曲谱详情'
        }
      },
      {
        path: '/memberCenter',
        name: 'memberCenter',
        component: () => import('@/tenant/member-center/index'),
        meta: {
          title: '会员中心'
        }
      },
      {
        path: '/orderDetail',
        name: 'orderDetail',
        component: () => import('@/views/order-detail/index'),
        meta: {
          title: '订单详情'
        }
      },
      {
        path: '/music-personal',
        component: () => import('@/tenant/music/personal'),
        meta: {
          title: '我的曲库'
        }
      },
      {
        path: '/train-tool',
        component: () => import('@/tenant/music/train-tool'),
        meta: {
          title: '训练工具'
        }
      },
      {
        path: '/look-album-list',
        component: () => import('@/tenant/music/look-album-list'),
        meta: {
          title: '查看专辑'
        }
      },
      {
        path: '/exercise-record',
        name: 'exercise-record',
        component: () => import('@/tenant/exercise-record/exercis-detail'),
        meta: {
          title: '练习统计'
        }
      },
      {
        path: '/activation-code',
        name: 'activation-code',
        component: () => import('@/tenant/activation-code'),
        meta: {
          title: '激活码'
        }
      },
      {
        path: '/ranking-list',
        name: 'ranking-list',
        component: () => import('@/tenant/ranking-list'),
        meta: {
          title: '排行榜'
        }
      },
      {
        path: '/goodsOrder',
        name: 'goodsOrder',
        component: () => import('@/tenant/trade/index'),
        meta: {
          title: '交易记录'
        }
      },
      {
        path: '/music-songbook',
        component: () => import('@/tenant/music/search/header'),
        meta: {
          title: '搜索顶部'
        },
        children: [
          {
            path: '/music-songbook/search',
            name: 'musicSearch',
            component: () => import('@/tenant/music/search'),
            meta: {
              title: '搜索结果'
            }
          },
          {
            path: '',
            name: 'musicSongbook',
            component: () => import('@/tenant/music/songbook'),
            meta: {
              title: '乐谱库'
            }
          }
        ]
      },
      // {
      //   path: '/practiceClass',
      //   name: 'practiceClass',
      //   component: () => import('@/student/practice-class/index'),
      //   meta: {
      //     title: '陪练课'
      //   }
      // },
      // {
      //   path: '/videoDetail',
      //   name: 'videoDetail',
      //   component: () => import('@/student/video-class/video-detail'),
      //   meta: {
      //     title: '视频课'
      //   }
      // },
      // {
      //   path: '/videoClassDetail',
      //   name: 'videoClassDetail',
      //   component: () => import('@/student/video-class/video-class-detail'),
      //   meta: {
      //     title: '视频课详情'
      //   }
      // },
      // {
      //   path: '/liveDetail',
      //   name: 'liveDetail',
      //   component: () => import('@/student/live-class/live-detail'),
      //   meta: {
      //     title: '直播课详情'
      //   }
      // },
      // {
      //   path: '/memberActive',
      //   name: 'memberActive',
      //   component: () => import('@/student/member-center/member-active'),
      //   meta: {
      //     title: '小酷Ai会员大放价'
      //   }
      // },
      {
        path: '/memberRecord',
        name: 'memberRecord',
        component: () => import('@/tenant/exercise-record/exercis-detail'),
        meta: {
          title: '训练统计'
        }
      }
      // {
      //   path: '/tradeRecord',
      //   name: 'tradeRecord',
      //   component: () => import('@/student/trade/index'),
      //   meta: {
      //     title: '交易记录'
      //   }
      // },
      // {
      //   path: '/teacherHome',
      //   name: 'teacherHome',
      //   component: () => import('@/student/teacher-dependent/teacher-home'),
      //   meta: {
      //     title: '老师主页'
      //   }
      // },
      // {
      //   path: '/teacherElegant',
      //   name: 'teacherElegant',
      //   component: () => import('@/student/teacher-dependent/teacher-elegant'),
      //   meta: {
      //     title: '老师风采'
      //   }
      // },
      // {
      //   path: '/music-upload',
      //   component: () => import('@/teacher/music/upload'),
      //   meta: {
      //     title: '上传曲谱'
      //   }
      // },
      // {
      //   path: '/teacherFollow',
      //   component: () => import('@/student/teacher-dependent/teacher-follow'),
      //   meta: {
      //     title: '我的关注'
      //   }
      // },
      // {
      //   path: '/track-review-activity',
      //   component: () =>
      //     import('@/student/share-active/track-review-activity/index'),
      //   meta: {
      //     title: '曲目评测活动',
      //     isExternal: true // 是否外部浏览器可以打开
      //   }
      // },

      // {
      //   path: '/track-song',
      //   component: () =>
      //     import('@/student/share-active/track-review-activity/track-song'),
      //   meta: {
      //     title: '评测曲目'
      //   }
      // }
    ]
  },
  ...noLoginRouter,
  // ...rootRouter,
  {
    path: '/:pathMatch(.*)*',
    component: () => import('@/views/404'),
    meta: {
      title: '404 Not Fund',
      platform: 'STUDENT'
    }
  }
]
