import { Sticky, Cell, Tag, Icon, Popup, Tabs, Tab, Dialog, Button } from 'vant'
import {
  RouterView,
  useRouter,
  useRoute,
  onBeforeRouteUpdate
} from 'vue-router'
import { defineComponent, nextTick, onMounted, reactive, ref, watch } from 'vue'
import mitt from 'mitt'
import Search from '@/components/col-search'
import { useLocalStorage } from '@vueuse/core'
import styles from './index.module.less'
import classNames from 'classnames'
import SelectTag from './select-tag'
import { getRandomKey } from '../music'
import SelectSubject from './select-subject'
import { SubjectEnum, useSubjectId } from '@/helpers/hooks'
import { state } from '@/state'
import TheSticky from '@/components/the-sticky'
import bgImg from '../../images/bg-image.png'

export const mitter = mitt()

const selectTagRef = ref()

export default defineComponent({
  name: 'MusicSearchHeader',
  setup() {
    const subjects: any = useSubjectId(SubjectEnum.SEARCH)
    // 判断是否已有数据
    if (!subjects.id) {
      const users = state.user.data
      const subjectId = users.subjectId
        ? Number(users.subjectId.split(',')[0])
        : ''
      const subjectName = users.subjectName
        ? users.subjectName.split(',')[0]
        : ''
      if (subjectId) {
        useSubjectId(
          SubjectEnum.SEARCH,
          JSON.stringify({
            id: subjectId,
            name: subjectName
          }),
          'set'
        )
      }
    }

    const searchInputRef = ref()
    localStorage.setItem('behaviorId', getRandomKey())
    const router = useRouter()
    const route = useRoute()
    const keyword = ref('')
    const tagids = ref('')
    const tagVisibility = ref(false)
    const words = useLocalStorage<string[]>('music-search', [])
    const activeTab = ref('songe')

    onBeforeRouteUpdate(() => {
      const getSubject: any = useSubjectId(SubjectEnum.SEARCH)
      subject.name = getSubject.name || '全部声部'
      subject.id = getSubject.id
      if (route.path === '/music-songbook/search') {
        keyword.value = ''
        tagids.value = ''
        activeTab.value = 'songe'
        try {
          selectTagRef.value?.resetTags?.()
        } catch (error) {
          console.log(error)
        }
      }
      return true
    })

    watch(activeTab, val => {
      mitter.emit('changeTab', val)
    })

    const onSearch = val => {
      keyword.value = val
      const indexOf = words.value.indexOf(val)
      if (indexOf > -1) {
        words.value.splice(indexOf, 1)
      }
      if (val) {
        words.value.unshift(val)
        words.value.length = Math.min(words.value.length, 10)
      }
      mitter.emit('search', val)
    }

    const onComfirm = (tags, name = '') => {
      const data = Object.values(tags).flat().filter(Boolean).join(',')
      tagids.value = data
      mitter.emit('confirm', tags)
      tagVisibility.value = false
    }

    const onComfirmSubject = (item: any) => {
      // console.log('onSort', item)
      subject.name = item.name
      subject.id = item.id
      useSubjectId(
        SubjectEnum.SEARCH,
        JSON.stringify({
          id: item.id,
          name: item.name
        }),
        'set'
      )
      mitter.emit('confirmSubject', subject)
      subject.show = false
    }

    onMounted(() => {})

    const getSubject: any = useSubjectId(SubjectEnum.SEARCH)
    const subject = reactive({
      show: false,
      name: getSubject.name || '全部声部',
      id: getSubject.id || ''
    })

    // this.historyTag = [{id: 0, title: '血液病'},{id: 7, title: '血液病有哪几种'},
    //     {id: 3, title: '儿童淋巴瘤'}, {id: 4, title: '喉咙痛声音嘶哑'}, {id: 5, title: '咽喉癌的早期症状'},
    //     {id: 6, title: '成人淋巴癌'},{id: 1, title: '肺癌'},{id: 2, title: '白血病'}
    //   ]
    const tagRef = ref<any>([])
    const collapse = reactive({
      // historyTag:
      line: 1,
      arrowStatus: true
    })

    // 历史搜索默认收起
    const defaultClose = () => {
      nextTick(() => {
        if (!words.value || !words.value.length) {
          return
        }
        let offsetLeft = 0
        collapse.line = 0
        const tags = tagRef.value
        tags.forEach((item: any, index: number) => {
          try {
            console.log(index, '1212', 'tagRef', item)
            if (index === 0) {
              collapse.line = 1
              offsetLeft = item.$el.offsetLeft
            } else if (item.$el.offsetLeft === offsetLeft && index != 0) {
              // 如果某个标签的offsetLeft和第一个标签的offsetLeft相等  说明增加了一行
              collapse.line += 1
              console.log(11111, collapse.line)
            }

            if (collapse.line > 2) {
              //从第3行开始 隐藏标签
              item.$el.style.display = 'none'
              console.log(item.$el.style)
              // 显示展开按钮  class名chu是在前面动态添加的
              if (item.className === 'chu') {
                // item.style.display = 'inline-block'
                // item.style.marginTop = 0 + 'px'
              }
            }
          } catch (e: any) {
            console.log(e, 'Error')
          }
        })
        if (collapse.line > 2) {
          // 超过2行  手动添加“展开”按钮
          // words.value.push({id:0, title: '展开'})
        }

        console.log(collapse.line, 'collapse.line')
      })
    }
    // 历史搜索展开
    // const openAll = () => {
    //   let tags = tagRef
    //   let index = words.value.findIndex((item) => {
    //     return item.title === '展开'
    //   })
    //   // 展开状态  删除“展开”按钮
    //   words.value.splice(index, 1, )
    //   // 添加“收起”按钮
    //   words.value.splice(tags.length - 1, 0, {id:0, title: '收起'})
    //   // 将所有的标签都显示
    //   tags.forEach((item,index) => {
    //     item.style.display = 'inline-block'
    //   })
    // }

    // // 点击某个历史搜索
    // clickTag(item) {
    //   if (item.title === '展开') {
    //     this.openAll()
    //   } else if (item.title === '收起') {
    //     this.defaultClose()
    //   } else {

    //   }

    // }
    // 首先调用默认收起的方法
    defaultClose()

    return () => {
      return (
        <div class={styles.search}>
          <div class={styles.sticky}>
            <TheSticky position="top">
              <Search
                modelValue={keyword.value}
                background="transparent"
                ref={searchInputRef}
                onSearch={onSearch}
                type="tenant"
                v-slots={{
                  left: () => (
                    <div
                      class={styles.label}
                      onClick={() => (subject.show = true)}
                    >
                      {subject.name}
                      <Icon
                        classPrefix="iconfont"
                        name="down"
                        size={12}
                        color="#333"
                      />
                    </div>
                  )
                }}
              />
              {/* {route.path === '/music-songbook/search' && (
              <Tabs
                color="var(--van-primary)"
                background="transparent"
                lineWidth={20}
                shrink
                v-model:active={activeTab.value}
                onChange={val => (activeTab.value = val)}
              >
                <Tab title="单曲" name="songe"></Tab>
                <Tab title="专辑" name="album"></Tab>
              </Tabs>
            )} */}
            </TheSticky>
            <img class={styles.bgImg} src={bgImg} />
          </div>
          {words.value.length > 0 && route.path === '/music-songbook/search' && (
            <div class={styles.keywordSection}>
              <div class={styles.keywordTitle}>
                <span class={styles.t}>搜索历史</span>
                <Icon
                  class={styles.remove}
                  name="delete-o"
                  onClick={() => (words.value = [])}
                />
              </div>
              <div class={classNames(styles.keywords)}>
                <div class={styles.content}>
                  {words.value.map((item: any, index: number) => (
                    <Tag
                      // ref={(el: any) => (tagRef[index] = el)}
                      ref={(el: any) => (tagRef.value[index] = el)}
                      round
                      class={[styles.searchKeyword, 'van-ellipsis']}
                      key={item}
                      onClick={() => onSearch(item)}
                    >
                      {item}
                    </Tag>
                  ))}
                  {collapse.line > 2 && (
                    <span class={styles.arrowMore}>
                      <Icon name={'arrow-down'} />
                    </span>
                  )}
                </div>
              </div>
            </div>
          )}
          {route.path === '/music-songbook/search' && (
            <Tabs
              color="var(--van-primary)"
              background="transparent"
              lineWidth={20}
              shrink
              class={styles.tagTabs}
              v-model:active={activeTab.value}
              onChange={val => (activeTab.value = val)}
            >
              <Tab title="单曲" name="songe"></Tab>
              <Tab title="专辑" name="album"></Tab>
            </Tabs>
          )}
          <RouterView />
          <Popup
            show={tagVisibility.value}
            round
            closeable
            position="bottom"
            style={{ height: '60%' }}
            teleport="body"
            onUpdate:show={val => (tagVisibility.value = val)}
          >
            <SelectTag
              ref={selectTagRef}
              onConfirm={onComfirm}
              onCancel={() => {}}
            />
          </Popup>

          {/* 声部弹框 */}
          <Popup
            show={subject.show}
            position="bottom"
            round
            closeable
            safe-area-inset-bottom
            onClose={() => (subject.show = false)}
            onClosed={() => (subject.show = false)}
          >
            <SelectSubject
              searchParams={subject}
              onComfirm={onComfirmSubject}
            />
          </Popup>
        </div>
      )
    }
  }
})
